/********************************************************************************
** Form generated from reading UI file 'person-details-presentation.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PERSON_2D_DETAILS_2D_PRESENTATION_H
#define UI_PERSON_2D_DETAILS_2D_PRESENTATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_PersonDetailsPresentation
{
public:
    QGridLayout *gridLayout;
    QLabel *detailsLabel;
    QLabel *avatarPixmapLabel;
    QSpacerItem *horizontalSpacer;
    QLabel *presencePixmapLabel;
    QLabel *nameLabel;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *PersonDetailsPresentation)
    {
        if (PersonDetailsPresentation->objectName().isEmpty())
            PersonDetailsPresentation->setObjectName("PersonDetailsPresentation");
        PersonDetailsPresentation->setMaximumSize(QSize(16777215, 96));
        gridLayout = new QGridLayout(PersonDetailsPresentation);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        detailsLabel = new QLabel(PersonDetailsPresentation);
        detailsLabel->setObjectName("detailsLabel");

        gridLayout->addWidget(detailsLabel, 1, 2, 1, 1);

        avatarPixmapLabel = new QLabel(PersonDetailsPresentation);
        avatarPixmapLabel->setObjectName("avatarPixmapLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(avatarPixmapLabel->sizePolicy().hasHeightForWidth());
        avatarPixmapLabel->setSizePolicy(sizePolicy);
        avatarPixmapLabel->setMinimumSize(QSize(0, 0));
        avatarPixmapLabel->setMaximumSize(QSize(96, 96));

        gridLayout->addWidget(avatarPixmapLabel, 0, 0, 4, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        presencePixmapLabel = new QLabel(PersonDetailsPresentation);
        presencePixmapLabel->setObjectName("presencePixmapLabel");
        presencePixmapLabel->setMaximumSize(QSize(64, 64));

        gridLayout->addWidget(presencePixmapLabel, 0, 1, 1, 1);

        nameLabel = new QLabel(PersonDetailsPresentation);
        nameLabel->setObjectName("nameLabel");

        gridLayout->addWidget(nameLabel, 0, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 2, 1, 1);


        retranslateUi(PersonDetailsPresentation);

        QMetaObject::connectSlotsByName(PersonDetailsPresentation);
    } // setupUi

    void retranslateUi(QWidget *PersonDetailsPresentation)
    {
        detailsLabel->setText(QString());
        avatarPixmapLabel->setText(tr2i18n("Avatar", nullptr));
        presencePixmapLabel->setText(QString());
        nameLabel->setText(QString());
        (void)PersonDetailsPresentation;
    } // retranslateUi

};

namespace Ui {
    class PersonDetailsPresentation: public Ui_PersonDetailsPresentation {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PERSON_2D_DETAILS_2D_PRESENTATION_H

