// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kpeopledeclarative_debug.h"


Q_LOGGING_CATEGORY(KPEOPLE_DECLARATIVE_LOG, "kf.people.declarative", QtInfoMsg)

