/****************************************************************************
** Meta object code from reading C++ file 'personsmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kpeople-6.27.0/src/personsmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'personsmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN7KPeople12PersonsModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KPeople::PersonsModel::qt_create_metaobjectdata<qt_meta_tag_ZN7KPeople12PersonsModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KPeople::PersonsModel",
        "modelInitialized",
        "",
        "success",
        "get",
        "QVariant",
        "row",
        "role",
        "isInitialized",
        "Role",
        "FormattedNameRole",
        "PhotoRole",
        "PersonUriRole",
        "PersonVCardRole",
        "ContactsVCardRole",
        "GroupsRole",
        "PhoneNumberRole",
        "PhotoImageProviderUri",
        "UserRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modelInitialized'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Method 'get'
        QtMocHelpers::MethodData<QVariant(int, int)>(4, 2, QMC::AccessPublic | QMC::MethodScriptable, 0x80000000 | 5, {{
            { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'isInitialized'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Role'
        QtMocHelpers::EnumData<enum Role>(9, 9, QMC::EnumFlags{}).add({
            {   10, Role::FormattedNameRole },
            {   11, Role::PhotoRole },
            {   12, Role::PersonUriRole },
            {   13, Role::PersonVCardRole },
            {   14, Role::ContactsVCardRole },
            {   15, Role::GroupsRole },
            {   16, Role::PhoneNumberRole },
            {   17, Role::PhotoImageProviderUri },
            {   18, Role::UserRole },
        }),
    };
    return QtMocHelpers::metaObjectData<PersonsModel, qt_meta_tag_ZN7KPeople12PersonsModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KPeople::PersonsModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPeople12PersonsModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPeople12PersonsModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN7KPeople12PersonsModelE_t>.metaTypes,
    nullptr
} };

void KPeople::PersonsModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PersonsModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modelInitialized((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: { QVariant _r = _t->get((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PersonsModel::*)(bool )>(_a, &PersonsModel::modelInitialized, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isInitialized(); break;
        default: break;
        }
    }
}

const QMetaObject *KPeople::PersonsModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KPeople::PersonsModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN7KPeople12PersonsModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int KPeople::PersonsModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KPeople::PersonsModel::modelInitialized(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
QT_WARNING_POP
