/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<declarativepersondata.h>)
#  include <declarativepersondata.h>
#endif
#if __has_include(<peopleqmlplugin.h>)
#  include <peopleqmlplugin.h>
#endif
#if __has_include(<personactionsmodel_p.h>)
#  include <personactionsmodel_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_people()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &ActionType::staticMetaObject;},
            "ActionType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&ActionType::staticMetaObject, "org.kde.people", 1, nullptr, &ActionType::staticMetaObject, nullptr);
    qmlRegisterEnum<ActionType::ActionType>("ActionType::ActionType");
    qmlRegisterTypesAndRevisions<DeclarativePersonData>("org.kde.people", 1);
    qmlRegisterTypesAndRevisions<DeclarativePersonPluginManager>("org.kde.people", 1);
    qmlRegisterTypesAndRevisions<KPeople::PersonActionsModel>("org.kde.people", 1);
    qmlRegisterTypesAndRevisions<PersonDataForeign>("org.kde.people", 1);
    qmlRegisterTypesAndRevisions<PersonsModelForeign>("org.kde.people", 1);
    qmlRegisterEnum<KPeople::PersonsModel::Role>("KPeople::PersonsModel::Role");
    qmlRegisterTypesAndRevisions<PersonsSortFilterProxyModelForeign>("org.kde.people", 1);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.people", 1, 0);
}

static const QQmlModuleRegistration orgkdepeopleRegistration("org.kde.people", qml_register_types_org_kde_people);
