/****************************************************************************
** Meta object code from reading C++ file 'peopleqmlplugin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kpeople-6.27.0/src/declarative/peopleqmlplugin.h"
#include <QtCore/qmetatype.h>
#include <QtCore/qplugin.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'peopleqmlplugin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30DeclarativePersonPluginManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativePersonPluginManager::qt_create_metaobjectdata<qt_meta_tag_ZN30DeclarativePersonPluginManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativePersonPluginManager",
        "QML.Singleton",
        "true",
        "QML.Element",
        "PersonPluginManager",
        "addContact",
        "",
        "QVariantMap",
        "properties",
        "deleteContact",
        "uri"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'addContact'
        QtMocHelpers::MethodData<bool(const QVariantMap &)>(5, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Method 'deleteContact'
        QtMocHelpers::MethodData<bool(const QString &)>(9, 6, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Bool, {{
            { QMetaType::QString, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DeclarativePersonPluginManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativePersonPluginManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30DeclarativePersonPluginManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30DeclarativePersonPluginManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30DeclarativePersonPluginManagerE_t>.metaTypes,
    nullptr
} };

void DeclarativePersonPluginManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativePersonPluginManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->addContact((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->deleteContact((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *DeclarativePersonPluginManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativePersonPluginManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30DeclarativePersonPluginManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DeclarativePersonPluginManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN15PeopleQMLPluginE_t {};
} // unnamed namespace

template <> constexpr inline auto PeopleQMLPlugin::qt_create_metaobjectdata<qt_meta_tag_ZN15PeopleQMLPluginE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PeopleQMLPlugin"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PeopleQMLPlugin, qt_meta_tag_ZN15PeopleQMLPluginE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PeopleQMLPlugin::staticMetaObject = { {
    QMetaObject::SuperData::link<QQmlExtensionPlugin::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PeopleQMLPluginE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PeopleQMLPluginE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15PeopleQMLPluginE_t>.metaTypes,
    nullptr
} };

void PeopleQMLPlugin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PeopleQMLPlugin *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PeopleQMLPlugin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PeopleQMLPlugin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PeopleQMLPluginE_t>.strings))
        return static_cast<void*>(this);
    return QQmlExtensionPlugin::qt_metacast(_clname);
}

int PeopleQMLPlugin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQmlExtensionPlugin::qt_metacall(_c, _id, _a);
    return _id;
}

#ifdef QT_MOC_EXPORT_PLUGIN_V2
static constexpr unsigned char qt_pluginMetaDataV2_PeopleQMLPlugin[] = {
    0xbf, 
    // "IID"
    0x02,  0x78,  0x28,  'o',  'r',  'g',  '.',  'q', 
    't',  '-',  'p',  'r',  'o',  'j',  'e',  'c', 
    't',  '.',  'Q',  't',  '.',  'Q',  'Q',  'm', 
    'l',  'E',  'x',  't',  'e',  'n',  's',  'i', 
    'o',  'n',  'I',  'n',  't',  'e',  'r',  'f', 
    'a',  'c',  'e', 
    // "className"
    0x03,  0x6f,  'P',  'e',  'o',  'p',  'l',  'e', 
    'Q',  'M',  'L',  'P',  'l',  'u',  'g',  'i', 
    'n', 
    // command-line "uri"
    0x63,  'u',  'r',  'i',  0x81,  0x6e,  'o',  'r', 
    'g',  '.',  'k',  'd',  'e',  '.',  'p',  'e', 
    'o',  'p',  'l',  'e', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN_V2(PeopleQMLPlugin, PeopleQMLPlugin, qt_pluginMetaDataV2_PeopleQMLPlugin)
#else
QT_PLUGIN_METADATA_SECTION
Q_CONSTINIT static constexpr unsigned char qt_pluginMetaData_PeopleQMLPlugin[] = {
    'Q', 'T', 'M', 'E', 'T', 'A', 'D', 'A', 'T', 'A', ' ', '!',
    // metadata version, Qt version, architectural requirements
    0, QT_VERSION_MAJOR, QT_VERSION_MINOR, qPluginArchRequirements(),
    0xbf, 
    // "IID"
    0x02,  0x78,  0x28,  'o',  'r',  'g',  '.',  'q', 
    't',  '-',  'p',  'r',  'o',  'j',  'e',  'c', 
    't',  '.',  'Q',  't',  '.',  'Q',  'Q',  'm', 
    'l',  'E',  'x',  't',  'e',  'n',  's',  'i', 
    'o',  'n',  'I',  'n',  't',  'e',  'r',  'f', 
    'a',  'c',  'e', 
    // "className"
    0x03,  0x6f,  'P',  'e',  'o',  'p',  'l',  'e', 
    'Q',  'M',  'L',  'P',  'l',  'u',  'g',  'i', 
    'n', 
    // command-line "uri"
    0x63,  'u',  'r',  'i',  0x81,  0x6e,  'o',  'r', 
    'g',  '.',  'k',  'd',  'e',  '.',  'p',  'e', 
    'o',  'p',  'l',  'e', 
    0xff, 
};
QT_MOC_EXPORT_PLUGIN(PeopleQMLPlugin, PeopleQMLPlugin)
#endif  // QT_MOC_EXPORT_PLUGIN_V2

namespace {
struct qt_meta_tag_ZN17PersonDataForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonDataForeign::qt_create_metaobjectdata<qt_meta_tag_ZN17PersonDataForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonDataForeign",
        "QML.Foreign",
        "KPeople::PersonData",
        "QML.Element",
        "anonymous"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PersonDataForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PersonDataForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PersonDataForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17PersonDataForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17PersonDataForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN19PersonsModelForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonsModelForeign::qt_create_metaobjectdata<qt_meta_tag_ZN19PersonsModelForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonsModelForeign",
        "QML.Foreign",
        "KPeople::PersonsModel",
        "QML.Element",
        "PersonsModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PersonsModelForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PersonsModelForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PersonsModelForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19PersonsModelForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19PersonsModelForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN34PersonsSortFilterProxyModelForeignE_t {};
} // unnamed namespace

template <> constexpr inline auto PersonsSortFilterProxyModelForeign::qt_create_metaobjectdata<qt_meta_tag_ZN34PersonsSortFilterProxyModelForeignE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PersonsSortFilterProxyModelForeign",
        "QML.Foreign",
        "KPeople::PersonsSortFilterProxyModel",
        "QML.Element",
        "PersonsSortFilterProxyModel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<PersonsSortFilterProxyModelForeign, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PersonsSortFilterProxyModelForeign::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34PersonsSortFilterProxyModelForeignE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN34PersonsSortFilterProxyModelForeignE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN34PersonsSortFilterProxyModelForeignE_t>.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN10ActionTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto ActionType::qt_create_metaobjectdata<qt_meta_tag_ZN10ActionTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ActionType",
        "QML.Element",
        "auto",
        "TextChatAction",
        "AudioCallAction",
        "VideoCallAction",
        "SendEmailAction",
        "SendFileAction",
        "OtherAction"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ActionType'
        QtMocHelpers::EnumData<ActionType>(0, 0, QMC::EnumFlags{}).add({
            {    3, ActionType::TextChatAction },
            {    4, ActionType::AudioCallAction },
            {    5, ActionType::VideoCallAction },
            {    6, ActionType::SendEmailAction },
            {    7, ActionType::SendFileAction },
            {    8, ActionType::OtherAction },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN10ActionTypeE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN10ActionTypeE =
    ActionType::qt_create_metaobjectdata<qt_meta_tag_ZN10ActionTypeE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN10ActionTypeE =
    qt_staticMetaObjectContent_ZN10ActionTypeE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN10ActionTypeE =
    qt_staticMetaObjectContent_ZN10ActionTypeE.relocatingData;

Q_CONSTINIT const QMetaObject ActionType::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN10ActionTypeE.stringdata,
    qt_staticMetaObjectStaticContent_ZN10ActionTypeE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN10ActionTypeE.metaTypes,
    nullptr
} };

QT_WARNING_POP
